#
# spec file for package pugixml
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _libname libpugixml1
Name:           pugixml
Version:        1.9
Release:        lp150.1.1
Summary:        Light-weight C++ XML Processing Library
License:        MIT
Group:          System/Libraries
Url:            http://pugixml.org/
Source0:        https://github.com/zeux/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Patch1:         pugixml-config.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
pugixml is a light-weight C++ XML processing library. It features:

- DOM-like interface with rich traversal/modification capabilities
- Extremely fast non-validating XML parser which constructs the DOM tree from
  an XML file/buffer
- XPath 1.0 implementation for complex data-driven tree queries
- Full Unicode support with Unicode interface variants and automatic encoding
  conversions

The library is extremely portable and easy to integrate and use.

%package devel
Summary:        Development Files for pugixml
Group:          Development/Libraries/C and C++
Requires:       %{_libname} = %{version}

%description devel
This package provides development libraries and headers needed to build
software using pugixml.

%package -n %{_libname}
Summary:        Light-weight C++ XML Processing Library
Group:          System/Libraries

%description -n %{_libname}
pugixml is a light-weight C++ XML processing library. It features:

- DOM-like interface with rich traversal/modification capabilities
- Extremely fast non-validating XML parser which constructs the DOM tree from
  an XML file/buffer
- XPath 1.0 implementation for complex data-driven tree queries
- Full Unicode support with Unicode interface variants and automatic encoding
  conversions

The library is extremely portable and easy to integrate and use.

%prep
%setup -q
%patch1 -p1

%build
%cmake
make %{?_smp_mflags}

%install
%cmake_install

%post -n %{_libname} -p /sbin/ldconfig

%postun -n %{_libname} -p /sbin/ldconfig

%files devel
%defattr(-,root,root,-)
%doc readme.txt docs/*
%{_includedir}/*.hpp
%{_libdir}/cmake/*
%{_libdir}/*.so

%files -n %{_libname}
%defattr(-,root,root,-)
%{_libdir}/libpugixml.so.*

%changelog
* Tue Apr 10 2018 bjoern@schramke-online.de
- Update to version 1.9
  * Specification changes
    + xml_document::load(const char*) (deprecated in 1.5) now has
    deprecated attribute; use xml_document::load_string instead
    + xml_node::select_single_node (deprecated in 1.5) now has
    deprecated attribute; use xml_node::select_node instead
  * New features
    + Add move semantics support for xml_document and improve
    move semantics support for other objects
    + CMake build now exports include directories
    + CMake build with BUILD_SHARED_LIBS=ON now uses dllexport
    attribute for MSVC
  * XPath improvements
    + Rework parser/evaluator to not rely on exceptional control
    flow; longjmp is no longer used when exceptions are disabled
    + Improve error messages for certain invalid expressions such
    as .[1] or (1
    + Minor performance improvements
  * Compatibility improvements
    + Fix Texas Instruments compiler warnings
    + Fix compilation issues with limits.h for some versions of gcc
    + Fix compilation issues with Clang/C2
    + Fix implicit fallthrough warnings in gcc 7
    + Fix unknown attribute directive warnings in gcc 8
    + Fix cray++ compiler errors
    + Fix unsigned integer overflow errors with -fsanitize=integer
    + Fix undefined behavior sanitizer issues in compact mode
* Thu Feb 16 2017 joerg.lorenzen@ki.tng.de
- Update to version 1.8
  * Specification changes
    + When printing empty elements, a space is no longer added
    before / in format_raw mode.
  * New features
    + Added parse_embed_pcdata parsing mode in which PCDATA value
    is stored in the element node if possible (significantly
    reducing memory consumption for some documents).
    + Added auto-detection support for Latin-1 (ISO-8859-1)
    encoding during parsing.
    + Added format_no_empty_element_tags formatting flag that
    outputs start/end tags instead of empty element tags for
    empty elements.
  * Performance improvements
    + Minor memory allocation improvements (yielding up to 1%%
    memory savings in some cases).
  * Compatibility improvements
    + Fixed compilation issues for Borland C++ 5.4.
    + Fixed compilation issues for some distributions of MinGW 3.8.
    + Fixed various Clang/GCC warnings.
    + Enabled move semantics support for XPath objects for MSVC
    2010 and above.
* Wed Oct 21 2015 idonmez@suse.com
- Update to version 1.7
  * New integer parsing/formatting implementation
    + Functions that convert from and to integers (e.g. as_int/set_value)
    do not rely on CRT any more.
    + New implementation is 3-5x faster and is always correct wrt
    overflow or underflow. This is a behavior change - where previously
    as_uint() would return UINT_MAX on a value "-1", it now returns 0.
  * New features
    + XPath objects (xpath_query, xpath_node_set, xpath_variable_set)
    are now movable if your compiler supports C++11. Additionally,
    xpath_variable_set is copyable.
    + Added format_indent_attributes that makes the resulting XML friendlier
    to line diff/merge tools.
    + Added a variant of xml_node::attribute function with a hint that
    can improve lookup performance.
    + Custom allocation functions are now allowed (but not required)
    to throw instead of returning a null pointer.
  * Bug fixes
    + Fix Clang 3.7 crashes in out-of-memory cases (C++ DR 1748)
    + Fix xpath_node_set assignment to provide strong exception guarantee
    + Fix saving for custom xml_writer implementations that can throw from write()
- Add pugixml-config.patch to enable long long support, works better than
  enabling via build flags.
* Fri Oct  9 2015 idonmez@suse.com
- Manually enable long long support
* Fri Sep  4 2015 tchvatal@suse.com
- Version bump to 1.6:
  * See manual.html for in-depth changelog
- Use %%cmake macros properly
* Thu Mar  5 2015 davejplater@gmail.com
- Update to version 1.5 and prepare for submission to factory
  See bnc#905649 enable blender cycles. Pugixml needed by OpenImageIO
  needed by blender for cycles.
- Upstream changes:
  see http://cdn.rawgit.com/zeux/pugixml/v1.5/docs/manual/changes.html
* Tue Jul 15 2014 asterios.dramis@gmail.com
- Update to version 1.4:
  Specification changes:
  * Documents without element nodes are now rejected with
    status_no_document_element error, unless parse_fragment option is used
  New features:
  * Added XML fragment parsing (parse_fragment flag)
  * Added PCDATA whitespace trimming (parse_trim_pcdata flag)
  * Added long long support for xml_attribute and xml_text (as_llong, as_ullong
    and set_value/set overloads)
  * Added hexadecimal integer parsing support for
    as_int/as_uint/as_llong/as_ullong
  * Added xml_node::append_buffer to improve performance of assembling
    documents from fragments
  * xml_named_node_iterator is now bidirectional
  * Reduced XPath stack consumption during compilation and evaluation (useful
    for embedded systems)
  Compatibility improvements:
  * Improved support for platforms without wchar_t support
  * Fixed several false positives in clang static analysis
  * Fixed several compilation warnings for various GCC versions
  Bug fixes:
  * Fixed undefined pointer arithmetic in XPath implementation
  * Fixed non-seekable iostream support for certain stream types, i.e. boost
    file_source with pipe input
  * Fixed xpath_query::return_type() for some expressions
  * Fixed dllexport issues with xml_named_node_iterator
  * Fixed find_child_by_attribute assertion for attributes with null name/value
- Removed fix_install_libdir.patch (not needed anynore).
* Tue Jun 24 2014 perry.werneck@gmail.com
- Small change in "make install" to fix SLES build.
* Sun Feb 17 2013 asterios.dramis@gmail.com
- Initial release (version 1.2).
- Added a patch (fix_install_libdir.patch) to make the package install the
  library in the correct libdir (lib or lib64).
